@@ -33,11 +33,11 @@ fn overview_bench(c: &mut Criterion) {
             // ranging from -1e9 to 1e9.
             let provider = icu_provider::inv::InvariantDataProvider;
             let fdf =
-                FixedDecimalFormat::try_new(Locale::und(), &provider, Default::default()).unwrap();
+                FixedDecimalFormat::try_new(Locale::UND, &provider, Default::default()).unwrap();
             nums.iter()
                 .map(|v| black_box(*v))
                 .map(FixedDecimal::from)
-                .map(|n| fdf.format(&n).writeable_to_string().into_owned())
+                .map(|n| fdf.format(&n).write_to_string().into_owned())
                 .count();
         });
     });
