@@ -9,8 +9,7 @@
 
 use fixed_decimal::FixedDecimal;
 use icu_decimal::{options, FixedDecimalFormat};
-use icu_locid::Locale;
-use icu_locid_macros::langid;
+use icu_locid::locale;
 use writeable::Writeable;
 
 icu_benchmark_macros::static_setup!();
@@ -27,27 +26,25 @@ const LINES_REMOVED_ADDED: [(i64, i64); 5] = [
 fn main(_argc: isize, _argv: *const *const u8) -> isize {
     icu_benchmark_macros::main_setup!();
 
-    let locale: Locale = langid!("bn").into();
-
-    let provider = icu_testdata::get_static_provider();
+    let provider = icu_testdata::get_provider();
 
     let mut options: options::FixedDecimalFormatOptions = Default::default();
     options.sign_display = options::SignDisplay::ExceptZero;
 
-    let fdf = FixedDecimalFormat::try_new(locale, &provider, options)
+    let fdf = FixedDecimalFormat::try_new(locale!("bn"), &provider, options)
         .expect("Failed to create FixedDecimalFormat instance.");
 
     for line in LINES_REMOVED_ADDED.iter() {
         let decimals: (FixedDecimal, FixedDecimal) = (line.0.into(), line.1.into());
         let removed = fdf.format(&decimals.0);
         let added = fdf.format(&decimals.1);
-        assert_ne!("", removed.writeable_to_string());
-        assert_ne!("", added.writeable_to_string());
+        assert_ne!("", removed.write_to_string());
+        assert_ne!("", added.write_to_string());
         #[cfg(debug_assertions)]
         println!(
             "Added/Removed: {}/{}",
-            removed.writeable_to_string(),
-            added.writeable_to_string()
+            removed.write_to_string(),
+            added.write_to_string()
         );
     }
 
