@@ -43,11 +43,12 @@ pub fn check(
 #[test]
 fn test_grouper() {
     use crate::options;
+    use crate::provider::*;
     use crate::FixedDecimalFormat;
     use fixed_decimal::FixedDecimal;
     use icu_locid::LanguageIdentifier;
     use icu_provider::prelude::*;
-    use icu_provider::struct_provider::AnyPayloadProvider;
+    use icu_provider_adapters::struct_provider::AnyPayloadProvider;
     use writeable::Writeable;
 
     let western_sizes = GroupingSizesV1 {
@@ -116,24 +117,22 @@ fn test_grouper() {
                 ..Default::default()
             };
             let provider = AnyPayloadProvider {
-                key: crate::provider::key::SYMBOLS_V1,
-                data: DataPayload::<crate::provider::DecimalSymbolsV1Marker>::from_owned(
-                    data_struct,
-                )
-                .wrap_into_any_payload(),
+                key: DecimalSymbolsV1Marker::KEY,
+                data: DataPayload::<DecimalSymbolsV1Marker>::from_owned(data_struct)
+                    .wrap_into_any_payload(),
             };
             let options = options::FixedDecimalFormatOptions {
                 grouping_strategy: cas.strategy,
                 ..Default::default()
             };
             let fdf = FixedDecimalFormat::try_new(
-                LanguageIdentifier::und(),
+                LanguageIdentifier::UND,
                 &provider.as_downcasting(),
                 options,
             )
             .unwrap();
             let actual = fdf.format(&dec);
-            assert_eq!(cas.expected[i], actual.writeable_to_string(), "{:?}", cas);
+            assert_eq!(cas.expected[i], actual.write_to_string(), "{:?}", cas);
         }
     }
 }
