@@ -18,18 +18,16 @@
 //!
 //! ```
 //! use icu::decimal::FixedDecimalFormat;
-//! use icu::locid::Locale;
-//! use icu::locid::macros::langid;
+//! use icu::locid::locale;
 //! use writeable::Writeable;
 //!
-//! let locale: Locale = langid!("bn").into();
 //! let provider = icu_testdata::get_provider();
-//! let fdf = FixedDecimalFormat::try_new(locale, &provider, Default::default())
+//! let fdf = FixedDecimalFormat::try_new(locale!("bn"), &provider, Default::default())
 //!     .expect("Data should load successfully");
 //!
 //! let fixed_decimal = 1000007.into();
 //! let formatted_value = fdf.format(&fixed_decimal);
-//! let formatted_str = formatted_value.writeable_to_string();
+//! let formatted_str = formatted_value.write_to_string();
 //!
 //! assert_eq!("১০,০০,০০৭", formatted_str);
 //! ```
@@ -42,21 +40,32 @@
 //! use icu::locid::Locale;
 //! use writeable::Writeable;
 //!
-//! let locale = Locale::und();
 //! let provider = icu_provider::inv::InvariantDataProvider;
-//! let fdf = FixedDecimalFormat::try_new(locale, &provider, Default::default())
+//! let fdf = FixedDecimalFormat::try_new(Locale::UND, &provider, Default::default())
 //!     .expect("Data should load successfully");
 //!
 //! let fixed_decimal = FixedDecimal::from(200050)
 //!     .multiplied_pow10(-2)
 //!     .expect("Operation is fully in range");
 //!
-//! assert_eq!("2,000.50", fdf.format(&fixed_decimal).writeable_to_string());
+//! assert_eq!("2,000.50", fdf.format(&fixed_decimal).write_to_string());
 //! ```
 //!
 //! [`FixedDecimalFormat`]: FixedDecimalFormat
 
+// https://github.com/unicode-org/icu4x/blob/main/docs/process/boilerplate.md#library-annotations
 #![cfg_attr(not(any(test, feature = "std")), no_std)]
+#![cfg_attr(
+    not(test),
+    deny(
+        clippy::indexing_slicing,
+        clippy::unwrap_used,
+        clippy::expect_used,
+        clippy::panic,
+        clippy::exhaustive_structs,
+        clippy::exhaustive_enums
+    )
+)]
 
 extern crate alloc;
 
@@ -92,20 +101,18 @@ pub struct FixedDecimalFormat {
 
 impl FixedDecimalFormat {
     /// Creates a new [`FixedDecimalFormat`] from locale data and an options bag.
-    pub fn try_new<T: Into<Locale>, D: DataProvider<provider::DecimalSymbolsV1Marker> + ?Sized>(
+    pub fn try_new<
+        T: Into<Locale>,
+        D: ResourceProvider<provider::DecimalSymbolsV1Marker> + ?Sized,
+    >(
         locale: T,
         data_provider: &D,
         options: options::FixedDecimalFormatOptions,
     ) -> Result<Self, FixedDecimalFormatError> {
         let symbols = data_provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: provider::key::SYMBOLS_V1,
-                    options: ResourceOptions {
-                        variant: None,
-                        langid: Some(locale.into().into()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: locale.into().into(),
+                metadata: Default::default(),
             })?
             .take_payload()?;
         Ok(Self { options, symbols })
