@@ -6,40 +6,31 @@
 //!
 //! Read more about data providers: [`icu_provider`]
 
+// Provider structs must be stable
+#![allow(clippy::exhaustive_structs)]
+
 use alloc::borrow::Cow;
-use icu_provider::yoke::{self, *};
-
-pub mod key {
-    //! Resource keys for [`icu_decimal`](crate).
-    use icu_provider::{resource_key, ResourceKey};
-
-    /// Resource key: symbols used for basic decimal formatting.
-    pub const SYMBOLS_V1: ResourceKey = resource_key!("decimal/symbols@1");
-}
+use icu_provider::{yoke, zerofrom};
 
 /// A collection of strings to affix to a decimal number.
-#[derive(Debug, PartialEq, Clone, Yokeable, ZeroCopyFrom)]
-#[cfg_attr(
-    feature = "provider_serde",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[derive(Debug, PartialEq, Clone, yoke::Yokeable, zerofrom::ZeroFrom)]
+#[cfg_attr(feature = "datagen", derive(serde::Serialize))]
+#[cfg_attr(feature = "serde", derive(serde::Deserialize))]
 pub struct AffixesV1<'data> {
     /// String to prepend before the decimal number.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub prefix: Cow<'data, str>,
 
     /// String to append after the decimal number.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub suffix: Cow<'data, str>,
 }
 
 /// A collection of settings expressing where to put grouping separators in a decimal number.
 /// For example, `1,000,000` has two grouping separators, positioned along every 3 digits.
-#[derive(Debug, PartialEq, Clone, Yokeable, Copy, ZeroCopyFrom)]
-#[cfg_attr(
-    feature = "provider_serde",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[derive(Debug, PartialEq, Clone, yoke::Yokeable, Copy, zerofrom::ZeroFrom)]
+#[cfg_attr(feature = "datagen", derive(serde::Serialize))]
+#[cfg_attr(feature = "serde", derive(serde::Deserialize))]
 pub struct GroupingSizesV1 {
     /// The size of the first (lowest-magnitude) group.
     pub primary: u8,
@@ -53,27 +44,25 @@ pub struct GroupingSizesV1 {
 }
 
 /// Symbols and metadata required for formatting a [`FixedDecimal`](crate::FixedDecimal).
-#[icu_provider::data_struct]
+#[icu_provider::data_struct(DecimalSymbolsV1Marker = "decimal/symbols@1")]
 #[derive(Debug, PartialEq, Clone)]
-#[cfg_attr(
-    feature = "provider_serde",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[cfg_attr(feature = "datagen", derive(serde::Serialize))]
+#[cfg_attr(feature = "serde", derive(serde::Deserialize))]
 pub struct DecimalSymbolsV1<'data> {
     /// Prefix and suffix to apply when a negative sign is needed.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub minus_sign_affixes: AffixesV1<'data>,
 
     /// Prefix and suffix to apply when a plus sign is needed.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub plus_sign_affixes: AffixesV1<'data>,
 
     /// Character used to separate the integer and fraction parts of the number.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub decimal_separator: Cow<'data, str>,
 
     /// Character used to separate groups in the integer part of the number.
-    #[cfg_attr(feature = "provider_serde", serde(borrow))]
+    #[cfg_attr(feature = "serde", serde(borrow))]
     pub grouping_separator: Cow<'data, str>,
 
     /// Settings used to determine where to place groups in the integer part of the number.
